@@ -36,6 +36,7 @@ summary.bmgarch <- function(object, CrI = c(.025, .975), digits = 2, ...) {
     # Parameters for each model
     common_params <- c("lp__", "nu")
     arma_params <- c("phi0", "phi", "theta")
+    var_params <- c("phi0", "phi")
 
     ccc_params <- c("c_h", "a_h", "b_h", "R", "beta", "c_h_var")
     dcc_params <- c("c_h", "a_h", "b_h", "beta", "c_h_var", "a_q", "b_q", "S")
@@ -43,7 +44,9 @@ summary.bmgarch <- function(object, CrI = c(.025, .975), digits = 2, ...) {
     
     # Meta-data needed for printing
     # TODO: Revisit this; some can be removed. Kitchen sink for now.
-    metaNames <- c("param", "distribution", "num_dist", "iter", "chains", "elapsed_time", "date", "nt", "TS_names", "mgarchQ", "mgarchP", "meanstructure")
+    metaNames <- c("param", "distribution", "num_dist", "iter", "chains",
+                   "elapsed_time", "date", "nt", "TS_names", "mgarchQ",
+                   "mgarchP", "meanstructure", "sampling_algorithm")
     meta <- with(object, mget(metaNames))
     meta$xC <- !all(object$xC == 0)
     out <- list()
@@ -52,10 +55,10 @@ summary.bmgarch <- function(object, CrI = c(.025, .975), digits = 2, ...) {
 
     # Get the model summaries. print.summary.bmgarch will process this + meta.
     params <- switch(object$param,
-                     CCC = c(ccc_params, arma_params, common_params),
-                     DCC = c(dcc_params, arma_params, common_params),
-                     BEKK = c(bekk_params, arma_params, common_params),
-                     pdBEKK = c(bekk_params, arma_params, common_params),
+                     CCC = c(ccc_params, arma_params, var_params, common_params),
+                     DCC = c(dcc_params, arma_params, var_params, common_params),
+                     BEKK = c(bekk_params, arma_params, var_params, common_params),
+                     pdBEKK = c(bekk_params, arma_params, var_params, common_params),
                      NULL
                      )
     if(is.null(params)) {
@@ -63,7 +66,8 @@ summary.bmgarch <- function(object, CrI = c(.025, .975), digits = 2, ...) {
              object$param, "is not one in ", paste0(supported_models, collapse = ", "), ".")
     }
 
-    out$model_summary <- .get_stan_summary(object$model_fit, params, CrI)
+    out$model_summary <- .get_stan_summary(object$model_fit, params, CrI,
+                                           sampling_algorithm = object$sampling_algorithm)
 
     class(out) <- "summary.bmgarch"
     return(out)
@@ -74,16 +78,24 @@ summary.bmgarch <- function(object, CrI = c(.025, .975), digits = 2, ...) {
 ##' @param params Character vector. Names of params to pull from stan summary.
 ##' @param CrI Numeric vector (length 2).
 ##' @param weights Numeric vector. Weights for each model in model_fit, if list.
+##' @param sampling_algorithm Character vector for sampling method.
 ##' @return Stan summary for parameters. Columns: mean, sd, mdn, and CrIs.
 ##' @author Stephen R. Martin, Philippe Rast
 ##' @keywords internal
-.get_stan_summary <- function(model_fit, params, CrI, weights = NULL) {
-    if(class(model_fit) == "stanfit" | (class(model_fit) == "list" & length(model_fit) == 1)) { # One model fit
-        if(class(model_fit) == "list") {
-            model_fit <- model_fit[[1]]
-        }
+.get_stan_summary <- function(model_fit, params, CrI, weights = NULL, sampling_algorithm ) {
+    ## Check if we are dealing with 1 or multiple models
+    if (inherits(model_fit, "stanfit") || (inherits(model_fit, "list") && length(model_fit) == 1)) {
+      if (inherits(model_fit, "list")) {
+        model_fit <- model_fit[[1]]
+      }
         CrI <- c(.5, CrI)
-        cols <- c("mean","sd",paste0(CrI*100, "%"), "n_eff", "Rhat")
+        if(sampling_algorithm == 'MCMC') {
+            cols <- c("mean","sd",paste0(CrI*100, "%"), "n_eff", "Rhat")            
+        } else { ## VB does not return n_eff and Rhat
+            if(sampling_algorithm == 'VB' ) {
+                cols <- c("mean","sd",paste0(CrI*100, "%"))                
+            }
+        }
         model_summary <- rstan::summary(model_fit, pars = params, probs = CrI)$summary[,cols]
         colnames(model_summary)[colnames(model_summary) == "50%"] <- "mdn"
         return(model_summary)
@@ -162,7 +174,7 @@ summary.bmgarch <- function(object, CrI = c(.025, .975), digits = 2, ...) {
 ##' @param x summary.bmgarch object.
 ##' @param ... Not used.
 ##' @return x (invisible).
-##' @author Stephen R. Martin
+##' @author Philippe Rast, Stephen R. Martin
 ##' @export
 print.summary.bmgarch <- function(x, ...) {
     if(x$meta$param == "CCC") {
@@ -174,7 +186,7 @@ print.summary.bmgarch <- function(x, ...) {
     }
     .newline(2)
 
-    .print.summary.arma(x)
+    .print.summary.means(x)
     .newline(2)
 
     if(x$meta$xC) {
@@ -194,12 +206,10 @@ print.summary.bmgarch <- function(x, ...) {
 }
 ##' @title Print helper for CCC.
 ##' @param bmsum summary.bmgarch object.
-##' @param x bmgarch.summary object.
-##' @param ... Not used.
 ##' @return Void.
 ##' @author Stephen R. Martin, Philippe Rast
 ##' @keywords internal
-.print.summary.ccc <- function(bmsum, ...) {
+.print.summary.ccc <- function(bmsum) {
     # Meta-data
     cat("Model:", paste0(bmsum$meta$param, "-MGARCH\n"))
     cat("Basic Specification: ")
@@ -495,12 +505,12 @@ print.summary.bmgarch <- function(x, ...) {
     print(round( B_out, digits = digits) )
 }
 
-##' @title Print helper for ARMA component.
+##' @title Print helper for means component.
 ##' @param bmsum summary.bmgarch object.
 ##' @return Void.
 ##' @author Stephen R. Martin, Philippe Rast
 ##' @keywords internal
-.print.summary.arma <- function(bmsum) {
+.print.summary.means <- function(bmsum) {
     ms <- bmsum$model_summary
     nt <- bmsum$meta$nt
     TS_names <- bmsum$meta$TS_names
@@ -521,17 +531,21 @@ print.summary.bmgarch <- function(x, ...) {
     rownames(ms)[ma_index] <- paste0("Theta_", TS_names[ma_indices[,1]], "-", TS_names[ma_indices[,2]])
 
     if(bmsum$meta$meanstructure == 0) {
-        arma_index <- intercept_index
+        means_index <- intercept_index
         msg <- "Intercept estimates on the location:"
-    } else {
-        arma_index <- c(intercept_index, ar_index, ma_index)
+    } else if(bmsum$meta$meanstructure == 1) {
+        means_index <- c(intercept_index, ar_index, ma_index)
         msg <- "ARMA(1,1) estimates on the location:"
+    } else if(bmsum$meta$meanstructure == 2) {
+        means_index <- c(intercept_index, ar_index)
+        msg <- "VAR(1) estimates on the location:"       
     }
     cat(msg)
     .newline(2)
-    print(round(ms[arma_index,], digits = bmsum$meta$digits))
+    print(round(ms[means_index,], digits = bmsum$meta$digits))
 }
 
+
 ##' @title Print helper for beta component.
 ##' @param bmsum summary.bmgarch object.
 ##' @return Void.
@@ -637,6 +651,8 @@ print.summary.bmgarch <- function(x, ...) {
 ##' @author Stephen R. Martin, Philippe Rast
 ##' @keywords internal
 .print.config <- function(bmsum) {
+    .newline()
+    cat("Sampling Algorithm: ", bmsum$meta$sampling_algorithm)
     .newline()
     cat("Distribution: ", bmsum$meta$distribution)
     .newline()
@@ -646,8 +662,12 @@ print.summary.bmgarch <- function(x, ...) {
     cat("Chains: ", bmsum$meta$chains)
     .newline()
     cat("Date: ", bmsum$meta$date)
-    .newline()
-    cat("Elapsed time (min): ", round((max(bmsum$meta$elapsed_time[,1]) + max(bmsum$meta$elapsed_time[,2]))/60, 2))
+    if( !is.null( bmsum$meta$elapsed_time ) ) {
+        .newline()
+        cat("Elapsed time (min): ", round((max(bmsum$meta$elapsed_time[,1]) + max(bmsum$meta$elapsed_time[,2]))/60, 2))
+    } else {
+        warning("VB is not fully functional yet.",
+            "\n", "Use only for exploration -- for inference run models with \"sampling_algorithm = 'MCMC'\" ", call. = FALSE)
+    }
     .newline(2)
-    
 }
